@@ -4,6 +4,8 @@
 #include <QMainWindow>
 #include <QGraphicsView>
 #include <QGeoServiceProvider>
+#include <QMenu>
+#include <QMenuBar>
 
 #include "locationprovider.h"
 #include "mapwidget.h"
@@ -34,7 +36,12 @@ class MainWindow : public QMainWindow {
   // called from map whenever the user clicked a cache icon
   void selectCache(const QString &);
 
+ private slots:
+  void about();
+
  private:
+  void createMenu();
+
   QGeoServiceProvider *m_serviceProvider;
   MapWidget *m_mapWidget;
   GcProvider m_cacheProvider;
